/****************************************************************************
** Meta object code from reading C++ file 'bookmarksmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.04.3/src/lib/bookmarks/bookmarksmanager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bookmarksmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16BookmarksManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto BookmarksManager::qt_create_metaobjectdata<qt_meta_tag_ZN16BookmarksManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BookmarksManager",
        "search",
        "",
        "string",
        "bookmarkActivated",
        "BookmarkItem*",
        "item",
        "bookmarkCtrlActivated",
        "bookmarkShiftActivated",
        "bookmarksSelected",
        "QList<BookmarkItem*>",
        "items",
        "createContextMenu",
        "QPoint",
        "pos",
        "openBookmark",
        "openBookmarkInNewTab",
        "openBookmarkInNewWindow",
        "openBookmarkInNewPrivateWindow",
        "addBookmark",
        "addFolder",
        "addSeparator",
        "deleteBookmarks",
        "bookmarkEdited",
        "descriptionEdited",
        "enableUpdates"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'search'
        QtMocHelpers::SlotData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'bookmarkActivated'
        QtMocHelpers::SlotData<void(BookmarkItem *)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'bookmarkCtrlActivated'
        QtMocHelpers::SlotData<void(BookmarkItem *)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'bookmarkShiftActivated'
        QtMocHelpers::SlotData<void(BookmarkItem *)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'bookmarksSelected'
        QtMocHelpers::SlotData<void(const QList<BookmarkItem*> &)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'createContextMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'openBookmark'
        QtMocHelpers::SlotData<void(BookmarkItem *)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'openBookmark'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'openBookmarkInNewTab'
        QtMocHelpers::SlotData<void(BookmarkItem *)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'openBookmarkInNewTab'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'openBookmarkInNewWindow'
        QtMocHelpers::SlotData<void(BookmarkItem *)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'openBookmarkInNewWindow'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'openBookmarkInNewPrivateWindow'
        QtMocHelpers::SlotData<void(BookmarkItem *)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'openBookmarkInNewPrivateWindow'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'addBookmark'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addFolder'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addSeparator'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteBookmarks'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'bookmarkEdited'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'descriptionEdited'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'enableUpdates'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BookmarksManager, qt_meta_tag_ZN16BookmarksManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BookmarksManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16BookmarksManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16BookmarksManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16BookmarksManagerE_t>.metaTypes,
    nullptr
} };

void BookmarksManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BookmarksManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->search((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->bookmarkActivated((*reinterpret_cast<std::add_pointer_t<BookmarkItem*>>(_a[1]))); break;
        case 2: _t->bookmarkCtrlActivated((*reinterpret_cast<std::add_pointer_t<BookmarkItem*>>(_a[1]))); break;
        case 3: _t->bookmarkShiftActivated((*reinterpret_cast<std::add_pointer_t<BookmarkItem*>>(_a[1]))); break;
        case 4: _t->bookmarksSelected((*reinterpret_cast<std::add_pointer_t<QList<BookmarkItem*>>>(_a[1]))); break;
        case 5: _t->createContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 6: _t->openBookmark((*reinterpret_cast<std::add_pointer_t<BookmarkItem*>>(_a[1]))); break;
        case 7: _t->openBookmark(); break;
        case 8: _t->openBookmarkInNewTab((*reinterpret_cast<std::add_pointer_t<BookmarkItem*>>(_a[1]))); break;
        case 9: _t->openBookmarkInNewTab(); break;
        case 10: _t->openBookmarkInNewWindow((*reinterpret_cast<std::add_pointer_t<BookmarkItem*>>(_a[1]))); break;
        case 11: _t->openBookmarkInNewWindow(); break;
        case 12: _t->openBookmarkInNewPrivateWindow((*reinterpret_cast<std::add_pointer_t<BookmarkItem*>>(_a[1]))); break;
        case 13: _t->openBookmarkInNewPrivateWindow(); break;
        case 14: _t->addBookmark(); break;
        case 15: _t->addFolder(); break;
        case 16: _t->addSeparator(); break;
        case 17: _t->deleteBookmarks(); break;
        case 18: _t->bookmarkEdited(); break;
        case 19: _t->descriptionEdited(); break;
        case 20: _t->enableUpdates(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< BookmarkItem* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< BookmarkItem* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< BookmarkItem* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<BookmarkItem*> >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< BookmarkItem* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< BookmarkItem* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< BookmarkItem* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< BookmarkItem* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *BookmarksManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BookmarksManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16BookmarksManagerE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int BookmarksManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}
QT_WARNING_POP
