/********************************************************************************
** Form generated from reading UI file 'useragentdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_USERAGENTDIALOG_H
#define UI_USERAGENTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_UserAgentDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QCheckBox *changeGlobal;
    QComboBox *globalComboBox;
    QFrame *line;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *changePerSite;
    QFrame *perSiteFrame;
    QHBoxLayout *horizontalLayout;
    QTableWidget *table;
    QVBoxLayout *verticalLayout;
    QPushButton *add;
    QPushButton *remove;
    QSpacerItem *verticalSpacer;
    QPushButton *edit;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *UserAgentDialog)
    {
        if (UserAgentDialog->objectName().isEmpty())
            UserAgentDialog->setObjectName("UserAgentDialog");
        UserAgentDialog->resize(504, 377);
        verticalLayout_2 = new QVBoxLayout(UserAgentDialog);
        verticalLayout_2->setObjectName("verticalLayout_2");
        changeGlobal = new QCheckBox(UserAgentDialog);
        changeGlobal->setObjectName("changeGlobal");

        verticalLayout_2->addWidget(changeGlobal);

        globalComboBox = new QComboBox(UserAgentDialog);
        globalComboBox->setObjectName("globalComboBox");
        globalComboBox->setEditable(true);
        globalComboBox->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
        globalComboBox->setFrame(false);

        verticalLayout_2->addWidget(globalComboBox);

        line = new QFrame(UserAgentDialog);
        line->setObjectName("line");

        verticalLayout_2->addWidget(line);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setSpacing(0);
        verticalLayout_3->setObjectName("verticalLayout_3");
        changePerSite = new QCheckBox(UserAgentDialog);
        changePerSite->setObjectName("changePerSite");

        verticalLayout_3->addWidget(changePerSite);

        perSiteFrame = new QFrame(UserAgentDialog);
        perSiteFrame->setObjectName("perSiteFrame");
        horizontalLayout = new QHBoxLayout(perSiteFrame);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(-1, 4, -1, -1);
        table = new QTableWidget(perSiteFrame);
        if (table->columnCount() < 2)
            table->setColumnCount(2);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        table->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        table->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        table->setObjectName("table");
        table->setEditTriggers(QAbstractItemView::NoEditTriggers);
        table->setAlternatingRowColors(true);
        table->setSelectionMode(QAbstractItemView::SingleSelection);
        table->setSelectionBehavior(QAbstractItemView::SelectRows);
        table->setShowGrid(false);
        table->setSortingEnabled(true);
        table->setWordWrap(false);
        table->horizontalHeader()->setStretchLastSection(true);
        table->verticalHeader()->setVisible(false);
        table->verticalHeader()->setDefaultSectionSize(25);

        horizontalLayout->addWidget(table);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        add = new QPushButton(perSiteFrame);
        add->setObjectName("add");

        verticalLayout->addWidget(add);

        remove = new QPushButton(perSiteFrame);
        remove->setObjectName("remove");

        verticalLayout->addWidget(remove);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        edit = new QPushButton(perSiteFrame);
        edit->setObjectName("edit");

        verticalLayout->addWidget(edit);


        horizontalLayout->addLayout(verticalLayout);


        verticalLayout_3->addWidget(perSiteFrame);


        verticalLayout_2->addLayout(verticalLayout_3);

        buttonBox = new QDialogButtonBox(UserAgentDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(UserAgentDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, UserAgentDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, UserAgentDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(UserAgentDialog);
    } // setupUi

    void retranslateUi(QDialog *UserAgentDialog)
    {
        UserAgentDialog->setWindowTitle(QCoreApplication::translate("UserAgentDialog", "User Agent Manager", nullptr));
        changeGlobal->setText(QCoreApplication::translate("UserAgentDialog", "Change global User Agent", nullptr));
        changePerSite->setText(QCoreApplication::translate("UserAgentDialog", "Use different User Agents for specified sites", nullptr));
        QTableWidgetItem *___qtablewidgetitem = table->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(QCoreApplication::translate("UserAgentDialog", "Site", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = table->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(QCoreApplication::translate("UserAgentDialog", "User Agent", nullptr));
        add->setText(QCoreApplication::translate("UserAgentDialog", "Add", nullptr));
        remove->setText(QCoreApplication::translate("UserAgentDialog", "Remove", nullptr));
        edit->setText(QCoreApplication::translate("UserAgentDialog", "Edit", nullptr));
    } // retranslateUi

};

namespace Ui {
    class UserAgentDialog: public Ui_UserAgentDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_USERAGENTDIALOG_H
