/********************************************************************************
** Form generated from reading UI file 'desktopnotification.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DESKTOPNOTIFICATION_H
#define UI_DESKTOPNOTIFICATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_DesktopNotification
{
public:
    QVBoxLayout *verticalLayout;
    QFrame *frame;
    QHBoxLayout *horizontalLayout;
    QLabel *icon;
    QVBoxLayout *verticalLayout_2;
    QSpacerItem *verticalSpacer;
    QLabel *heading;
    QLabel *text;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *DesktopNotification)
    {
        if (DesktopNotification->objectName().isEmpty())
            DesktopNotification->setObjectName("DesktopNotification");
        DesktopNotification->resize(356, 74);
        verticalLayout = new QVBoxLayout(DesktopNotification);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        frame = new QFrame(DesktopNotification);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Raised);
        horizontalLayout = new QHBoxLayout(frame);
        horizontalLayout->setObjectName("horizontalLayout");
        icon = new QLabel(frame);
        icon->setObjectName("icon");
        icon->setMaximumSize(QSize(48, 48));

        horizontalLayout->addWidget(icon);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        heading = new QLabel(frame);
        heading->setObjectName("heading");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(heading->sizePolicy().hasHeightForWidth());
        heading->setSizePolicy(sizePolicy);

        verticalLayout_2->addWidget(heading);

        text = new QLabel(frame);
        text->setObjectName("text");
        text->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        verticalLayout_2->addWidget(text);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);


        horizontalLayout->addLayout(verticalLayout_2);


        verticalLayout->addWidget(frame);


        retranslateUi(DesktopNotification);

        QMetaObject::connectSlotsByName(DesktopNotification);
    } // setupUi

    void retranslateUi(QWidget *DesktopNotification)
    {
        icon->setText(QString());
        heading->setText(QString());
        text->setText(QString());
        (void)DesktopNotification;
    } // retranslateUi

};

namespace Ui {
    class DesktopNotification: public Ui_DesktopNotification {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DESKTOPNOTIFICATION_H
