/****************************************************************************
** Meta object code from reading C++ file 'tabcontextmenu.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.04.3/src/lib/tabwidget/tabcontextmenu.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tabcontextmenu.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14TabContextMenuE_t {};
} // unnamed namespace

template <> constexpr inline auto TabContextMenu::qt_create_metaobjectdata<qt_meta_tag_ZN14TabContextMenuE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TabContextMenu",
        "reloadTab",
        "",
        "index",
        "stopTab",
        "tabCloseRequested",
        "closeAllButCurrent",
        "closeToRight",
        "closeToLeft",
        "duplicateTab",
        "detachTab",
        "loadTab",
        "unloadTab",
        "closeTab",
        "pinTab",
        "muteTab"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'reloadTab'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'stopTab'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'tabCloseRequested'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'closeAllButCurrent'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'closeToRight'
        QtMocHelpers::SignalData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'closeToLeft'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'duplicateTab'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'detachTab'
        QtMocHelpers::SignalData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'loadTab'
        QtMocHelpers::SignalData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'unloadTab'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'reloadTab'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stopTab'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'closeTab'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'duplicateTab'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'detachTab'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'loadTab'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'unloadTab'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'pinTab'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'muteTab'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'closeAllButCurrent'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'closeToRight'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'closeToLeft'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TabContextMenu, qt_meta_tag_ZN14TabContextMenuE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TabContextMenu::staticMetaObject = { {
    QMetaObject::SuperData::link<QMenu::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14TabContextMenuE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14TabContextMenuE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14TabContextMenuE_t>.metaTypes,
    nullptr
} };

void TabContextMenu::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TabContextMenu *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->reloadTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->stopTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->tabCloseRequested((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->closeAllButCurrent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->closeToRight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->closeToLeft((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->duplicateTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->detachTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->loadTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->unloadTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->reloadTab(); break;
        case 11: _t->stopTab(); break;
        case 12: _t->closeTab(); break;
        case 13: _t->duplicateTab(); break;
        case 14: _t->detachTab(); break;
        case 15: _t->loadTab(); break;
        case 16: _t->unloadTab(); break;
        case 17: _t->pinTab(); break;
        case 18: _t->muteTab(); break;
        case 19: _t->closeAllButCurrent(); break;
        case 20: _t->closeToRight(); break;
        case 21: _t->closeToLeft(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TabContextMenu::*)(int )>(_a, &TabContextMenu::reloadTab, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabContextMenu::*)(int )>(_a, &TabContextMenu::stopTab, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabContextMenu::*)(int )>(_a, &TabContextMenu::tabCloseRequested, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabContextMenu::*)(int )>(_a, &TabContextMenu::closeAllButCurrent, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabContextMenu::*)(int )>(_a, &TabContextMenu::closeToRight, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabContextMenu::*)(int )>(_a, &TabContextMenu::closeToLeft, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabContextMenu::*)(int )>(_a, &TabContextMenu::duplicateTab, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabContextMenu::*)(int )>(_a, &TabContextMenu::detachTab, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabContextMenu::*)(int )>(_a, &TabContextMenu::loadTab, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabContextMenu::*)(int )>(_a, &TabContextMenu::unloadTab, 9))
            return;
    }
}

const QMetaObject *TabContextMenu::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TabContextMenu::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14TabContextMenuE_t>.strings))
        return static_cast<void*>(this);
    return QMenu::qt_metacast(_clname);
}

int TabContextMenu::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMenu::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void TabContextMenu::reloadTab(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void TabContextMenu::stopTab(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TabContextMenu::tabCloseRequested(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void TabContextMenu::closeAllButCurrent(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void TabContextMenu::closeToRight(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void TabContextMenu::closeToLeft(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void TabContextMenu::duplicateTab(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void TabContextMenu::detachTab(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void TabContextMenu::loadTab(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void TabContextMenu::unloadTab(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
