/********************************************************************************
** Form generated from reading UI file 'adblockdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADBLOCKDIALOG_H
#define UI_ADBLOCKDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_AdBlockDialog
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *adblockCheckBox;
    QHBoxLayout *horizontalLayout_3;
    QLineEdit *search;
    QSpacerItem *horizontalSpacer_2;
    QWidget *adblockWidget;
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QPushButton *buttonOptions;
    QSpacerItem *horizontalSpacer;
    QLabel *label;
    QTabWidget *tabWidget;
    QHBoxLayout *horizontalLayout_2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *AdBlockDialog)
    {
        if (AdBlockDialog->objectName().isEmpty())
            AdBlockDialog->setObjectName("AdBlockDialog");
        AdBlockDialog->resize(546, 462);
        verticalLayout = new QVBoxLayout(AdBlockDialog);
        verticalLayout->setObjectName("verticalLayout");
        adblockCheckBox = new QCheckBox(AdBlockDialog);
        adblockCheckBox->setObjectName("adblockCheckBox");
        adblockCheckBox->setChecked(true);

        verticalLayout->addWidget(adblockCheckBox);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        search = new QLineEdit(AdBlockDialog);
        search->setObjectName("search");

        horizontalLayout_3->addWidget(search);

        horizontalSpacer_2 = new QSpacerItem(50, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout_3);

        adblockWidget = new QWidget(AdBlockDialog);
        adblockWidget->setObjectName("adblockWidget");
        adblockWidget->setEnabled(true);
        gridLayout = new QGridLayout(adblockWidget);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        buttonOptions = new QPushButton(adblockWidget);
        buttonOptions->setObjectName("buttonOptions");
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/adblock/data/adblock.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        buttonOptions->setIcon(icon);

        horizontalLayout->addWidget(buttonOptions);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        label = new QLabel(adblockWidget);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(label);


        gridLayout->addLayout(horizontalLayout, 4, 0, 1, 2);

        tabWidget = new QTabWidget(adblockWidget);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setDocumentMode(true);

        gridLayout->addWidget(tabWidget, 2, 0, 1, 1);


        verticalLayout->addWidget(adblockWidget);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        buttonBox = new QDialogButtonBox(AdBlockDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Ok);

        horizontalLayout_2->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout_2);


        retranslateUi(AdBlockDialog);
        QObject::connect(adblockCheckBox, &QCheckBox::toggled, adblockWidget, &QWidget::setEnabled);

        tabWidget->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(AdBlockDialog);
    } // setupUi

    void retranslateUi(QDialog *AdBlockDialog)
    {
        AdBlockDialog->setWindowTitle(QCoreApplication::translate("AdBlockDialog", "AdBlock Configuration", nullptr));
        adblockCheckBox->setText(QCoreApplication::translate("AdBlockDialog", "Enable AdBlock", nullptr));
        search->setPlaceholderText(QCoreApplication::translate("AdBlockDialog", "Search...", nullptr));
        buttonOptions->setText(QCoreApplication::translate("AdBlockDialog", "Options", nullptr));
        label->setText(QCoreApplication::translate("AdBlockDialog", "AdBlock", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AdBlockDialog: public Ui_AdBlockDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ADBLOCKDIALOG_H
