/********************************************************************************
** Form generated from reading UI file 'fcm_notification.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FCM_NOTIFICATION_H
#define UI_FCM_NOTIFICATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "mactoolbutton.h"

QT_BEGIN_NAMESPACE

class Ui_FCM_Notification
{
public:
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLabel *textLabel;
    QPushButton *buttonView;
    QSpacerItem *horizontalSpacer;
    MacToolButton *close;

    void setupUi(QWidget *FCM_Notification)
    {
        if (FCM_Notification->objectName().isEmpty())
            FCM_Notification->setObjectName("FCM_Notification");
        FCM_Notification->resize(820, 36);
        horizontalLayout = new QHBoxLayout(FCM_Notification);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(-1, 0, -1, 0);
        label = new QLabel(FCM_Notification);
        label->setObjectName("label");
        label->setMinimumSize(QSize(24, 24));
        label->setMaximumSize(QSize(24, 24));
        label->setPixmap(QPixmap(QString::fromUtf8(":/flashcookiemanager/data/flash-cookie-manager.png")));
        label->setScaledContents(true);

        horizontalLayout->addWidget(label);

        textLabel = new QLabel(FCM_Notification);
        textLabel->setObjectName("textLabel");

        horizontalLayout->addWidget(textLabel);

        buttonView = new QPushButton(FCM_Notification);
        buttonView->setObjectName("buttonView");

        horizontalLayout->addWidget(buttonView);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        close = new MacToolButton(FCM_Notification);
        close->setObjectName("close");
        close->setAutoRaise(true);

        horizontalLayout->addWidget(close);


        retranslateUi(FCM_Notification);

        QMetaObject::connectSlotsByName(FCM_Notification);
    } // setupUi

    void retranslateUi(QWidget *FCM_Notification)
    {
        textLabel->setText(QCoreApplication::translate("FCM_Notification", "New flash cookie was detected!", nullptr));
        buttonView->setText(QCoreApplication::translate("FCM_Notification", "View", nullptr));
        close->setText(QString());
        (void)FCM_Notification;
    } // retranslateUi

};

namespace Ui {
    class FCM_Notification: public Ui_FCM_Notification {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FCM_NOTIFICATION_H
