/********************************************************************************
** Form generated from reading UI file 'tabmanagersettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TABMANAGERSETTINGS_H
#define UI_TABMANAGERSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_TabManagerSettings
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QRadioButton *sidebarRadio;
    QRadioButton *windowRadio;
    QLabel *label_2;
    QCheckBox *checkBox;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *TabManagerSettings)
    {
        if (TabManagerSettings->objectName().isEmpty())
            TabManagerSettings->setObjectName("TabManagerSettings");
        TabManagerSettings->resize(371, 237);
        verticalLayout_2 = new QVBoxLayout(TabManagerSettings);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBox = new QGroupBox(TabManagerSettings);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        sidebarRadio = new QRadioButton(groupBox);
        sidebarRadio->setObjectName("sidebarRadio");

        verticalLayout->addWidget(sidebarRadio);

        windowRadio = new QRadioButton(groupBox);
        windowRadio->setObjectName("windowRadio");

        verticalLayout->addWidget(windowRadio);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");
        label_2->setWordWrap(true);

        verticalLayout->addWidget(label_2);


        verticalLayout_2->addWidget(groupBox);

        checkBox = new QCheckBox(TabManagerSettings);
        checkBox->setObjectName("checkBox");

        verticalLayout_2->addWidget(checkBox);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(TabManagerSettings);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(TabManagerSettings);

        QMetaObject::connectSlotsByName(TabManagerSettings);
    } // setupUi

    void retranslateUi(QDialog *TabManagerSettings)
    {
        TabManagerSettings->setWindowTitle(QCoreApplication::translate("TabManagerSettings", "Tab Manager Settings", nullptr));
        groupBox->setTitle(QCoreApplication::translate("TabManagerSettings", "View", nullptr));
        label->setText(QCoreApplication::translate("TabManagerSettings", "Please select view type:", nullptr));
        sidebarRadio->setText(QCoreApplication::translate("TabManagerSettings", "SideBar", nullptr));
        windowRadio->setText(QCoreApplication::translate("TabManagerSettings", "Window", nullptr));
        label_2->setText(QCoreApplication::translate("TabManagerSettings", "<html><head/><body><p><span style=\" font-weight:600;\">Note:</span> The &quot;Window&quot; type is recommended for managing lots of windows/tabs.</p></body></html>", nullptr));
        checkBox->setText(QCoreApplication::translate("TabManagerSettings", "Use TabManager plugin as replacement for main TabBar.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TabManagerSettings: public Ui_TabManagerSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TABMANAGERSETTINGS_H
