/********************************************************************************
** Form generated from reading UI file 'sbi_settingsdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SBI_SETTINGSDIALOG_H
#define UI_SBI_SETTINGSDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_SBI_SettingsDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_3;
    QLabel *label;
    QLabel *label_2;
    QSpacerItem *horizontalSpacer_4;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer_2;
    QVBoxLayout *verticalLayout;
    QCheckBox *showImagesIcon;
    QCheckBox *showJavaScriptIcon;
    QCheckBox *showNetworkIcon;
    QCheckBox *showZoomWidget;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *SBI_SettingsDialog)
    {
        if (SBI_SettingsDialog->objectName().isEmpty())
            SBI_SettingsDialog->setObjectName("SBI_SettingsDialog");
        SBI_SettingsDialog->resize(343, 204);
        verticalLayout_2 = new QVBoxLayout(SBI_SettingsDialog);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);

        label = new QLabel(SBI_SettingsDialog);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);
        label->setPixmap(QPixmap(QString::fromUtf8(":/sbi/data/icon.png")));

        horizontalLayout_2->addWidget(label);

        label_2 = new QLabel(SBI_SettingsDialog);
        label_2->setObjectName("label_2");

        horizontalLayout_2->addWidget(label_2);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_4);


        verticalLayout_2->addLayout(horizontalLayout_2);

        label_3 = new QLabel(SBI_SettingsDialog);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignCenter);

        verticalLayout_2->addWidget(label_3);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        showImagesIcon = new QCheckBox(SBI_SettingsDialog);
        showImagesIcon->setObjectName("showImagesIcon");

        verticalLayout->addWidget(showImagesIcon);

        showJavaScriptIcon = new QCheckBox(SBI_SettingsDialog);
        showJavaScriptIcon->setObjectName("showJavaScriptIcon");

        verticalLayout->addWidget(showJavaScriptIcon);

        showNetworkIcon = new QCheckBox(SBI_SettingsDialog);
        showNetworkIcon->setObjectName("showNetworkIcon");

        verticalLayout->addWidget(showNetworkIcon);

        showZoomWidget = new QCheckBox(SBI_SettingsDialog);
        showZoomWidget->setObjectName("showZoomWidget");

        verticalLayout->addWidget(showZoomWidget);


        horizontalLayout->addLayout(verticalLayout);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout);

        buttonBox = new QDialogButtonBox(SBI_SettingsDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(SBI_SettingsDialog);

        QMetaObject::connectSlotsByName(SBI_SettingsDialog);
    } // setupUi

    void retranslateUi(QWidget *SBI_SettingsDialog)
    {
        SBI_SettingsDialog->setWindowTitle(QCoreApplication::translate("SBI_SettingsDialog", "StatusBar Icons", nullptr));
        label_2->setText(QCoreApplication::translate("SBI_SettingsDialog", "<h3>StatusBar Icons</h3>", nullptr));
        label_3->setText(QCoreApplication::translate("SBI_SettingsDialog", "These icons will be displayed in statusbar:", nullptr));
        showImagesIcon->setText(QCoreApplication::translate("SBI_SettingsDialog", "Images Icon", nullptr));
        showJavaScriptIcon->setText(QCoreApplication::translate("SBI_SettingsDialog", "JavaScript Icon", nullptr));
        showNetworkIcon->setText(QCoreApplication::translate("SBI_SettingsDialog", "Network Icon", nullptr));
        showZoomWidget->setText(QCoreApplication::translate("SBI_SettingsDialog", "Zoom widget", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SBI_SettingsDialog: public Ui_SBI_SettingsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SBI_SETTINGSDIALOG_H
