/********************************************************************************
** Form generated from reading UI file 'html5permissionsnotification.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_HTML5PERMISSIONSNOTIFICATION_H
#define UI_HTML5PERMISSIONSNOTIFICATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "mactoolbutton.h"

QT_BEGIN_NAMESPACE

class Ui_HTML5PermissionsNotification
{
public:
    QHBoxLayout *horizontalLayout;
    QLabel *textLabel;
    QSpacerItem *horizontalSpacer;
    QCheckBox *remember;
    QPushButton *allow;
    QPushButton *deny;
    MacToolButton *close;

    void setupUi(QWidget *HTML5PermissionsNotification)
    {
        if (HTML5PermissionsNotification->objectName().isEmpty())
            HTML5PermissionsNotification->setObjectName("HTML5PermissionsNotification");
        HTML5PermissionsNotification->resize(820, 36);
        horizontalLayout = new QHBoxLayout(HTML5PermissionsNotification);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(-1, 0, -1, 0);
        textLabel = new QLabel(HTML5PermissionsNotification);
        textLabel->setObjectName("textLabel");

        horizontalLayout->addWidget(textLabel);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        remember = new QCheckBox(HTML5PermissionsNotification);
        remember->setObjectName("remember");

        horizontalLayout->addWidget(remember);

        allow = new QPushButton(HTML5PermissionsNotification);
        allow->setObjectName("allow");

        horizontalLayout->addWidget(allow);

        deny = new QPushButton(HTML5PermissionsNotification);
        deny->setObjectName("deny");

        horizontalLayout->addWidget(deny);

        close = new MacToolButton(HTML5PermissionsNotification);
        close->setObjectName("close");
        close->setAutoRaise(true);

        horizontalLayout->addWidget(close);


        retranslateUi(HTML5PermissionsNotification);

        QMetaObject::connectSlotsByName(HTML5PermissionsNotification);
    } // setupUi

    void retranslateUi(QWidget *HTML5PermissionsNotification)
    {
        textLabel->setText(QString());
        remember->setText(QCoreApplication::translate("HTML5PermissionsNotification", "Remember", nullptr));
        allow->setText(QCoreApplication::translate("HTML5PermissionsNotification", "Allow", nullptr));
        deny->setText(QCoreApplication::translate("HTML5PermissionsNotification", "Deny", nullptr));
        close->setText(QString());
        (void)HTML5PermissionsNotification;
    } // retranslateUi

};

namespace Ui {
    class HTML5PermissionsNotification: public Ui_HTML5PermissionsNotification {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_HTML5PERMISSIONSNOTIFICATION_H
