/********************************************************************************
** Form generated from reading UI file 'bookmarkswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BOOKMARKSWIDGET_H
#define UI_BOOKMARKSWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>
#include "bookmarkstools.h"

QT_BEGIN_NAMESPACE

class Ui_BookmarksWidget
{
public:
    QGridLayout *gridLayout;
    QPushButton *bookmarksButton;
    QPushButton *speeddialButton;
    BookmarksFoldersButton *folderButton;

    void setupUi(QWidget *BookmarksWidget)
    {
        if (BookmarksWidget->objectName().isEmpty())
            BookmarksWidget->setObjectName("BookmarksWidget");
        BookmarksWidget->resize(167, 123);
        gridLayout = new QGridLayout(BookmarksWidget);
        gridLayout->setObjectName("gridLayout");
        bookmarksButton = new QPushButton(BookmarksWidget);
        bookmarksButton->setObjectName("bookmarksButton");
        bookmarksButton->setFlat(true);

        gridLayout->addWidget(bookmarksButton, 1, 0, 1, 1);

        speeddialButton = new QPushButton(BookmarksWidget);
        speeddialButton->setObjectName("speeddialButton");
        speeddialButton->setFocusPolicy(Qt::NoFocus);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/icons/theme/speeddial.png"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        speeddialButton->setIcon(icon);
        speeddialButton->setFlat(true);

        gridLayout->addWidget(speeddialButton, 0, 0, 1, 1);

        folderButton = new BookmarksFoldersButton(BookmarksWidget);
        folderButton->setObjectName("folderButton");

        gridLayout->addWidget(folderButton, 2, 0, 1, 1);


        retranslateUi(BookmarksWidget);

        QMetaObject::connectSlotsByName(BookmarksWidget);
    } // setupUi

    void retranslateUi(QWidget *BookmarksWidget)
    {
        BookmarksWidget->setWindowTitle(QString());
        bookmarksButton->setText(QCoreApplication::translate("BookmarksWidget", "Add to Bookmarks", nullptr));
        speeddialButton->setText(QCoreApplication::translate("BookmarksWidget", "Add to Speed Dial", nullptr));
    } // retranslateUi

};

namespace Ui {
    class BookmarksWidget: public Ui_BookmarksWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BOOKMARKSWIDGET_H
