/****************************************************************************
** Meta object code from reading C++ file 'bookmarkstreeview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.04.3/src/lib/bookmarks/bookmarkstreeview.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bookmarkstreeview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17BookmarksTreeViewE_t {};
} // unnamed namespace

template <> constexpr inline auto BookmarksTreeView::qt_create_metaobjectdata<qt_meta_tag_ZN17BookmarksTreeViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BookmarksTreeView",
        "bookmarkActivated",
        "",
        "BookmarkItem*",
        "item",
        "bookmarkCtrlActivated",
        "bookmarkShiftActivated",
        "contextMenuRequested",
        "QPoint",
        "point",
        "bookmarksSelected",
        "QList<BookmarkItem*>",
        "items",
        "search",
        "string",
        "indexExpanded",
        "QModelIndex",
        "parent",
        "indexCollapsed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bookmarkActivated'
        QtMocHelpers::SignalData<void(BookmarkItem *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'bookmarkCtrlActivated'
        QtMocHelpers::SignalData<void(BookmarkItem *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'bookmarkShiftActivated'
        QtMocHelpers::SignalData<void(BookmarkItem *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'contextMenuRequested'
        QtMocHelpers::SignalData<void(const QPoint &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'bookmarksSelected'
        QtMocHelpers::SignalData<void(const QList<BookmarkItem*> &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'search'
        QtMocHelpers::SlotData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'indexExpanded'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'indexCollapsed'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BookmarksTreeView, qt_meta_tag_ZN17BookmarksTreeViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BookmarksTreeView::staticMetaObject = { {
    QMetaObject::SuperData::link<QTreeView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17BookmarksTreeViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17BookmarksTreeViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17BookmarksTreeViewE_t>.metaTypes,
    nullptr
} };

void BookmarksTreeView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BookmarksTreeView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bookmarkActivated((*reinterpret_cast<std::add_pointer_t<BookmarkItem*>>(_a[1]))); break;
        case 1: _t->bookmarkCtrlActivated((*reinterpret_cast<std::add_pointer_t<BookmarkItem*>>(_a[1]))); break;
        case 2: _t->bookmarkShiftActivated((*reinterpret_cast<std::add_pointer_t<BookmarkItem*>>(_a[1]))); break;
        case 3: _t->contextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 4: _t->bookmarksSelected((*reinterpret_cast<std::add_pointer_t<QList<BookmarkItem*>>>(_a[1]))); break;
        case 5: _t->search((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->indexExpanded((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 7: _t->indexCollapsed((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BookmarksTreeView::*)(BookmarkItem * )>(_a, &BookmarksTreeView::bookmarkActivated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookmarksTreeView::*)(BookmarkItem * )>(_a, &BookmarksTreeView::bookmarkCtrlActivated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookmarksTreeView::*)(BookmarkItem * )>(_a, &BookmarksTreeView::bookmarkShiftActivated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookmarksTreeView::*)(const QPoint & )>(_a, &BookmarksTreeView::contextMenuRequested, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookmarksTreeView::*)(const QList<BookmarkItem*> & )>(_a, &BookmarksTreeView::bookmarksSelected, 4))
            return;
    }
}

const QMetaObject *BookmarksTreeView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BookmarksTreeView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17BookmarksTreeViewE_t>.strings))
        return static_cast<void*>(this);
    return QTreeView::qt_metacast(_clname);
}

int BookmarksTreeView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void BookmarksTreeView::bookmarkActivated(BookmarkItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BookmarksTreeView::bookmarkCtrlActivated(BookmarkItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BookmarksTreeView::bookmarkShiftActivated(BookmarkItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void BookmarksTreeView::contextMenuRequested(const QPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void BookmarksTreeView::bookmarksSelected(const QList<BookmarkItem*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
