/********************************************************************************
** Form generated from reading UI file 'sessionmanagerdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SESSIONMANAGERDIALOG_H
#define UI_SESSIONMANAGERDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_SessionManagerDialog
{
public:
    QGridLayout *gridLayout;
    QTreeWidget *treeWidget;
    QVBoxLayout *verticalLayout;
    QPushButton *newButton;
    QPushButton *renameButton;
    QPushButton *cloneButton;
    QPushButton *deleteButton;
    QPushButton *switchToButton;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SessionManagerDialog)
    {
        if (SessionManagerDialog->objectName().isEmpty())
            SessionManagerDialog->setObjectName("SessionManagerDialog");
        SessionManagerDialog->resize(466, 323);
        gridLayout = new QGridLayout(SessionManagerDialog);
        gridLayout->setObjectName("gridLayout");
        treeWidget = new QTreeWidget(SessionManagerDialog);
        treeWidget->setObjectName("treeWidget");
        treeWidget->setRootIsDecorated(false);

        gridLayout->addWidget(treeWidget, 0, 0, 1, 1);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        newButton = new QPushButton(SessionManagerDialog);
        newButton->setObjectName("newButton");

        verticalLayout->addWidget(newButton);

        renameButton = new QPushButton(SessionManagerDialog);
        renameButton->setObjectName("renameButton");

        verticalLayout->addWidget(renameButton);

        cloneButton = new QPushButton(SessionManagerDialog);
        cloneButton->setObjectName("cloneButton");

        verticalLayout->addWidget(cloneButton);

        deleteButton = new QPushButton(SessionManagerDialog);
        deleteButton->setObjectName("deleteButton");

        verticalLayout->addWidget(deleteButton);

        switchToButton = new QPushButton(SessionManagerDialog);
        switchToButton->setObjectName("switchToButton");

        verticalLayout->addWidget(switchToButton);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        gridLayout->addLayout(verticalLayout, 0, 1, 1, 1);

        buttonBox = new QDialogButtonBox(SessionManagerDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        gridLayout->addWidget(buttonBox, 1, 0, 1, 2);


        retranslateUi(SessionManagerDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, SessionManagerDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SessionManagerDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(SessionManagerDialog);
    } // setupUi

    void retranslateUi(QDialog *SessionManagerDialog)
    {
        SessionManagerDialog->setWindowTitle(QCoreApplication::translate("SessionManagerDialog", "Session Manager", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = treeWidget->headerItem();
        ___qtreewidgetitem->setText(1, QCoreApplication::translate("SessionManagerDialog", "Last Modified", nullptr));
        ___qtreewidgetitem->setText(0, QCoreApplication::translate("SessionManagerDialog", "Session", nullptr));
        newButton->setText(QCoreApplication::translate("SessionManagerDialog", "New", nullptr));
        renameButton->setText(QCoreApplication::translate("SessionManagerDialog", "Rename", nullptr));
        cloneButton->setText(QCoreApplication::translate("SessionManagerDialog", "Clone", nullptr));
        deleteButton->setText(QCoreApplication::translate("SessionManagerDialog", "Delete", nullptr));
        switchToButton->setText(QCoreApplication::translate("SessionManagerDialog", "Switch to", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SessionManagerDialog: public Ui_SessionManagerDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SESSIONMANAGERDIALOG_H
