/****************************************************************************
** Meta object code from reading C++ file 'opensearchengine.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.04.3/src/lib/opensearch/opensearchengine.h"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'opensearchengine.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16OpenSearchEngineE_t {};
} // unnamed namespace

template <> constexpr inline auto OpenSearchEngine::qt_create_metaobjectdata<qt_meta_tag_ZN16OpenSearchEngineE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OpenSearchEngine",
        "imageChanged",
        "",
        "suggestions",
        "requestSuggestions",
        "searchTerm",
        "requestSearchResults",
        "imageObtained",
        "suggestionsObtained",
        "name",
        "description",
        "searchUrlTemplate",
        "searchParameters",
        "Parameters",
        "searchMethod",
        "suggestionsUrlTemplate",
        "suggestionsParameters",
        "suggestionsMethod",
        "providesSuggestions",
        "imageUrl",
        "valid",
        "networkAccessManager",
        "QNetworkAccessManager*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'imageChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'suggestions'
        QtMocHelpers::SignalData<void(const QStringList &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'requestSuggestions'
        QtMocHelpers::SlotData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'requestSearchResults'
        QtMocHelpers::SlotData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'imageObtained'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'suggestionsObtained'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'name'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'searchUrlTemplate'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'searchParameters'
        QtMocHelpers::PropertyData<Parameters>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'searchMethod'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'suggestionsUrlTemplate'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'suggestionsParameters'
        QtMocHelpers::PropertyData<Parameters>(16, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'suggestionsMethod'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'providesSuggestions'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'imageUrl'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'valid'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'networkAccessManager'
        QtMocHelpers::PropertyData<QNetworkAccessManager*>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OpenSearchEngine, qt_meta_tag_ZN16OpenSearchEngineE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OpenSearchEngine::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16OpenSearchEngineE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16OpenSearchEngineE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16OpenSearchEngineE_t>.metaTypes,
    nullptr
} };

void OpenSearchEngine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OpenSearchEngine *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->imageChanged(); break;
        case 1: _t->suggestions((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 2: _t->requestSuggestions((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->requestSearchResults((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->imageObtained(); break;
        case 5: _t->suggestionsObtained(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OpenSearchEngine::*)()>(_a, &OpenSearchEngine::imageChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OpenSearchEngine::*)(const QStringList & )>(_a, &OpenSearchEngine::suggestions, 1))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 11:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QNetworkAccessManager* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->searchUrlTemplate(); break;
        case 3: *reinterpret_cast<Parameters*>(_v) = _t->searchParameters(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->searchMethod(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->suggestionsUrlTemplate(); break;
        case 6: *reinterpret_cast<Parameters*>(_v) = _t->suggestionsParameters(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->suggestionsMethod(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->providesSuggestions(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->imageUrl(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isValid(); break;
        case 11: *reinterpret_cast<QNetworkAccessManager**>(_v) = _t->networkAccessManager(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setDescription(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setSearchUrlTemplate(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setSearchParameters(*reinterpret_cast<Parameters*>(_v)); break;
        case 4: _t->setSearchMethod(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setSuggestionsUrlTemplate(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setSuggestionsParameters(*reinterpret_cast<Parameters*>(_v)); break;
        case 7: _t->setSuggestionsMethod(*reinterpret_cast<QString*>(_v)); break;
        case 9: _t->setImageUrl(*reinterpret_cast<QString*>(_v)); break;
        case 11: _t->setNetworkAccessManager(*reinterpret_cast<QNetworkAccessManager**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *OpenSearchEngine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OpenSearchEngine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16OpenSearchEngineE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int OpenSearchEngine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void OpenSearchEngine::imageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void OpenSearchEngine::suggestions(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
