/****************************************************************************
** Meta object code from reading C++ file 'mainapplication.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../falkon-26.04.3/src/lib/app/mainapplication.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainapplication.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15MainApplicationE_t {};
} // unnamed namespace

template <> constexpr inline auto MainApplication::qt_create_metaobjectdata<qt_meta_tag_ZN15MainApplicationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MainApplication",
        "settingsReloaded",
        "",
        "activeWindowChanged",
        "BrowserWindow*",
        "window",
        "addNewTab",
        "QUrl",
        "url",
        "startPrivateBrowsing",
        "startUrl",
        "reloadUserStyleSheet",
        "restoreOverrideCursor",
        "changeOccurred",
        "quitApplication",
        "postLaunch",
        "saveSettings",
        "messageReceived",
        "message",
        "windowDestroyed",
        "onFocusChanged",
        "runDeferredPostLaunchActions",
        "downloadRequested",
        "QWebEngineDownloadRequest*",
        "download"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'settingsReloaded'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeWindowChanged'
        QtMocHelpers::SignalData<void(BrowserWindow *)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'addNewTab'
        QtMocHelpers::SlotData<void(const QUrl &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'addNewTab'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'startPrivateBrowsing'
        QtMocHelpers::SlotData<void(const QUrl &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 10 },
        }}),
        // Slot 'startPrivateBrowsing'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'reloadUserStyleSheet'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'restoreOverrideCursor'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'changeOccurred'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'quitApplication'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'postLaunch'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveSettings'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'messageReceived'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'windowDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 5 },
        }}),
        // Slot 'onFocusChanged'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'runDeferredPostLaunchActions'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'downloadRequested'
        QtMocHelpers::SlotData<void(QWebEngineDownloadRequest *)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainApplication, qt_meta_tag_ZN15MainApplicationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MainApplication::staticMetaObject = { {
    QMetaObject::SuperData::link<QtSingleApplication::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15MainApplicationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15MainApplicationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15MainApplicationE_t>.metaTypes,
    nullptr
} };

void MainApplication::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainApplication *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->settingsReloaded(); break;
        case 1: _t->activeWindowChanged((*reinterpret_cast<std::add_pointer_t<BrowserWindow*>>(_a[1]))); break;
        case 2: _t->addNewTab((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 3: _t->addNewTab(); break;
        case 4: _t->startPrivateBrowsing((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 5: _t->startPrivateBrowsing(); break;
        case 6: _t->reloadUserStyleSheet(); break;
        case 7: _t->restoreOverrideCursor(); break;
        case 8: _t->changeOccurred(); break;
        case 9: _t->quitApplication(); break;
        case 10: _t->postLaunch(); break;
        case 11: _t->saveSettings(); break;
        case 12: _t->messageReceived((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->windowDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 14: _t->onFocusChanged(); break;
        case 15: _t->runDeferredPostLaunchActions(); break;
        case 16: _t->downloadRequested((*reinterpret_cast<std::add_pointer_t<QWebEngineDownloadRequest*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< BrowserWindow* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MainApplication::*)()>(_a, &MainApplication::settingsReloaded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainApplication::*)(BrowserWindow * )>(_a, &MainApplication::activeWindowChanged, 1))
            return;
    }
}

const QMetaObject *MainApplication::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainApplication::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15MainApplicationE_t>.strings))
        return static_cast<void*>(this);
    return QtSingleApplication::qt_metacast(_clname);
}

int MainApplication::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QtSingleApplication::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void MainApplication::settingsReloaded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MainApplication::activeWindowChanged(BrowserWindow * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
