/********************************************************************************
** Form generated from reading UI file 'searchtoolbar.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEARCHTOOLBAR_H
#define UI_SEARCHTOOLBAR_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include "focusselectlineedit.h"
#include "mactoolbutton.h"

QT_BEGIN_NAMESPACE

class Ui_SearchToolbar
{
public:
    QHBoxLayout *horizontalLayout;
    MacToolButton *closeButton;
    FocusSelectLineEdit *lineEdit;
    QToolButton *next;
    QToolButton *previous;
    QToolButton *caseSensitive;
    QLabel *resultsInfo;

    void setupUi(QWidget *SearchToolbar)
    {
        if (SearchToolbar->objectName().isEmpty())
            SearchToolbar->setObjectName("SearchToolbar");
        SearchToolbar->resize(855, 40);
        horizontalLayout = new QHBoxLayout(SearchToolbar);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(-1, 4, -1, 4);
        closeButton = new MacToolButton(SearchToolbar);
        closeButton->setObjectName("closeButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(closeButton->sizePolicy().hasHeightForWidth());
        closeButton->setSizePolicy(sizePolicy);
        closeButton->setAutoRaise(true);

        horizontalLayout->addWidget(closeButton);

        lineEdit = new FocusSelectLineEdit(SearchToolbar);
        lineEdit->setObjectName("lineEdit");
        lineEdit->setMinimumSize(QSize(100, 0));
        lineEdit->setMaximumSize(QSize(16777215, 16777215));
        lineEdit->setClearButtonEnabled(true);

        horizontalLayout->addWidget(lineEdit);

        next = new QToolButton(SearchToolbar);
        next->setObjectName("next");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("go-down-search")));
        next->setIcon(icon);
        next->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout->addWidget(next);

        previous = new QToolButton(SearchToolbar);
        previous->setObjectName("previous");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("go-up-search")));
        previous->setIcon(icon1);
        previous->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);

        horizontalLayout->addWidget(previous);

        caseSensitive = new QToolButton(SearchToolbar);
        caseSensitive->setObjectName("caseSensitive");
        caseSensitive->setCheckable(true);

        horizontalLayout->addWidget(caseSensitive);

        resultsInfo = new QLabel(SearchToolbar);
        resultsInfo->setObjectName("resultsInfo");

        horizontalLayout->addWidget(resultsInfo);


        retranslateUi(SearchToolbar);

        QMetaObject::connectSlotsByName(SearchToolbar);
    } // setupUi

    void retranslateUi(QWidget *SearchToolbar)
    {
        lineEdit->setPlaceholderText(QCoreApplication::translate("SearchToolbar", "Find...", nullptr));
#if QT_CONFIG(tooltip)
        next->setToolTip(QCoreApplication::translate("SearchToolbar", "Find the next match for the current search phrase", nullptr));
#endif // QT_CONFIG(tooltip)
        next->setText(QCoreApplication::translate("SearchToolbar", "&Next", nullptr));
#if QT_CONFIG(tooltip)
        previous->setToolTip(QCoreApplication::translate("SearchToolbar", "Find the previous match for the current search phrase", nullptr));
#endif // QT_CONFIG(tooltip)
        previous->setText(QCoreApplication::translate("SearchToolbar", "&Previous", nullptr));
        caseSensitive->setText(QCoreApplication::translate("SearchToolbar", "&Match Case", nullptr));
        resultsInfo->setText(QString());
        (void)SearchToolbar;
    } // retranslateUi

};

namespace Ui {
    class SearchToolbar: public Ui_SearchToolbar {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SEARCHTOOLBAR_H
