/********************************************************************************
** Form generated from reading UI file 'autoscrollsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AUTOSCROLLSETTINGS_H
#define UI_AUTOSCROLLSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_AutoScrollSettings
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_3;
    QSpacerItem *horizontalSpacer_3;
    QLabel *iconLabel;
    QSpacerItem *horizontalSpacer_4;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_2;
    QLabel *label_2;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer_5;
    QLabel *label_3;
    QDoubleSpinBox *divider;
    QSpacerItem *horizontalSpacer_6;
    QLabel *label_4;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *AutoScrollSettings)
    {
        if (AutoScrollSettings->objectName().isEmpty())
            AutoScrollSettings->setObjectName("AutoScrollSettings");
        AutoScrollSettings->resize(411, 179);
        verticalLayout = new QVBoxLayout(AutoScrollSettings);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_3);

        iconLabel = new QLabel(AutoScrollSettings);
        iconLabel->setObjectName("iconLabel");

        horizontalLayout_3->addWidget(iconLabel);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_4);


        verticalLayout->addLayout(horizontalLayout_3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        label_2 = new QLabel(AutoScrollSettings);
        label_2->setObjectName("label_2");

        horizontalLayout_2->addWidget(label_2);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_5);

        label_3 = new QLabel(AutoScrollSettings);
        label_3->setObjectName("label_3");

        horizontalLayout->addWidget(label_3);

        divider = new QDoubleSpinBox(AutoScrollSettings);
        divider->setObjectName("divider");
        divider->setMinimum(1.000000000000000);

        horizontalLayout->addWidget(divider);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_6);


        verticalLayout->addLayout(horizontalLayout);

        label_4 = new QLabel(AutoScrollSettings);
        label_4->setObjectName("label_4");

        verticalLayout->addWidget(label_4);

        buttonBox = new QDialogButtonBox(AutoScrollSettings);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(AutoScrollSettings);

        QMetaObject::connectSlotsByName(AutoScrollSettings);
    } // setupUi

    void retranslateUi(QDialog *AutoScrollSettings)
    {
        AutoScrollSettings->setWindowTitle(QCoreApplication::translate("AutoScrollSettings", "AutoScroll Settings", nullptr));
        label_2->setText(QCoreApplication::translate("AutoScrollSettings", "<h1>AutoScroll</h1>", nullptr));
        label_3->setText(QCoreApplication::translate("AutoScrollSettings", "Scroll Divider:", nullptr));
        label_4->setText(QCoreApplication::translate("AutoScrollSettings", "<b>Note:</b> Setting higher divider will slow down scrolling", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AutoScrollSettings: public Ui_AutoScrollSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_AUTOSCROLLSETTINGS_H
