/********************************************************************************
** Form generated from reading UI file 'thememanager.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_THEMEMANAGER_H
#define UI_THEMEMANAGER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "clickablelabel.h"

QT_BEGIN_NAMESPACE

class Ui_ThemeManager
{
public:
    QVBoxLayout *verticalLayout;
    QListWidget *listWidget;
    QWidget *widget;
    QFormLayout *formLayout;
    QLabel *label;
    QLabel *label_2;
    QLabel *author;
    QLabel *label_3;
    QLabel *description;
    QHBoxLayout *horizontalLayout;
    QLabel *name;
    ClickableLabel *license;
    QFrame *line;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *remove;
    QSpacerItem *horizontalSpacer;
    QLabel *label_4;

    void setupUi(QWidget *ThemeManager)
    {
        if (ThemeManager->objectName().isEmpty())
            ThemeManager->setObjectName("ThemeManager");
        ThemeManager->resize(512, 316);
        verticalLayout = new QVBoxLayout(ThemeManager);
        verticalLayout->setObjectName("verticalLayout");
        listWidget = new QListWidget(ThemeManager);
        listWidget->setObjectName("listWidget");
        listWidget->setIconSize(QSize(32, 32));

        verticalLayout->addWidget(listWidget);

        widget = new QWidget(ThemeManager);
        widget->setObjectName("widget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(widget->sizePolicy().hasHeightForWidth());
        widget->setSizePolicy(sizePolicy);
        formLayout = new QFormLayout(widget);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        formLayout->setContentsMargins(4, 4, 4, 4);
        label = new QLabel(widget);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        label_2 = new QLabel(widget);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        author = new QLabel(widget);
        author->setObjectName("author");
        author->setWordWrap(true);
        author->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, author);

        label_3 = new QLabel(widget);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_3);

        description = new QLabel(widget);
        description->setObjectName("description");
        description->setWordWrap(true);
        description->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, description);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        name = new QLabel(widget);
        name->setObjectName("name");
        name->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        horizontalLayout->addWidget(name);

        license = new ClickableLabel(widget);
        license->setObjectName("license");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(license->sizePolicy().hasHeightForWidth());
        license->setSizePolicy(sizePolicy1);
        license->setCursor(QCursor(Qt::CursorShape::PointingHandCursor));
        license->setProperty("html-link-look", QVariant(true));

        horizontalLayout->addWidget(license);


        formLayout->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout);


        verticalLayout->addWidget(widget);

        line = new QFrame(ThemeManager);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        remove = new QPushButton(ThemeManager);
        remove->setObjectName("remove");
        remove->setEnabled(false);

        horizontalLayout_2->addWidget(remove);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        label_4 = new QLabel(ThemeManager);
        label_4->setObjectName("label_4");
        label_4->setOpenExternalLinks(true);

        horizontalLayout_2->addWidget(label_4);


        verticalLayout->addLayout(horizontalLayout_2);


        retranslateUi(ThemeManager);

        QMetaObject::connectSlotsByName(ThemeManager);
    } // setupUi

    void retranslateUi(QWidget *ThemeManager)
    {
        label->setText(QCoreApplication::translate("ThemeManager", "<b>Name:</b>", nullptr));
        label_2->setText(QCoreApplication::translate("ThemeManager", "<b>Author:</b>", nullptr));
        author->setText(QString());
        label_3->setText(QCoreApplication::translate("ThemeManager", "<b>Description:</b>", nullptr));
        description->setText(QString());
        name->setText(QString());
        license->setText(QCoreApplication::translate("ThemeManager", "License", nullptr));
        remove->setText(QCoreApplication::translate("ThemeManager", "Remove", nullptr));
        label_4->setText(QCoreApplication::translate("ThemeManager", "<a href=\"https://store.kde.org/browse/cat/572/\">Get more themes...</a>", nullptr));
        (void)ThemeManager;
    } // retranslateUi

};

namespace Ui {
    class ThemeManager: public Ui_ThemeManager {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_THEMEMANAGER_H
